# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_util/util.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18th2_grpc_util/util.proto\x12\x04util\x1a\x1cth2_grpc_common/common.proto\"+\n\x12\x43omparisonSettings\x12\x15\n\rignore_fields\x18\x01 \x03(\t\"\x88\x01\n\x1e\x43ompareFilterVsMessagesRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.MessageFilter\x12\x1a\n\x08messages\x18\x02 \x03(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"a\n\x1f\x43ompareFilterVsMessagesResponse\x12>\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32\".util.CompareFilterVsMessageResult\"p\n\x1c\x43ompareFilterVsMessageResult\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry\"]\n\x1e\x43ompareMessageVsMessageRequest\x12;\n\x10\x63omparison_tasks\x18\x01 \x03(\x0b\x32!.util.CompareMessageVsMessageTask\"b\n\x1f\x43ompareMessageVsMessageResponse\x12?\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32#.util.CompareMessageVsMessageResult\"|\n\x1b\x43ompareMessageVsMessageTask\x12\x17\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x08.Message\x12\x18\n\x06second\x18\x02 \x01(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"\x9e\x01\n\x1d\x43ompareMessageVsMessageResult\x12$\n\x10\x66irst_message_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12%\n\x11second_message_id\x18\x02 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x03 \x01(\x0b\x32\x15.util.ComparisonEntry\"\xb4\x02\n\x0f\x43omparisonEntry\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.util.ComparisonEntryType\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.util.ComparisonEntryStatus\x12\r\n\x05\x66irst\x18\x03 \x01(\t\x12\x0e\n\x06second\x18\x04 \x01(\t\x12#\n\toperation\x18\x05 \x01(\x0e\x32\x10.FilterOperation\x12\x0e\n\x06is_key\x18\x06 \x01(\x08\x12\x31\n\x06\x66ields\x18\x07 \x03(\x0b\x32!.util.ComparisonEntry.FieldsEntry\x1a\x44\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry:\x02\x38\x01*0\n\x13\x43omparisonEntryType\x12\t\n\x05\x46IELD\x10\x00\x12\x0e\n\nCOLLECTION\x10\x01*7\n\x15\x43omparisonEntryStatus\x12\x06\n\x02NA\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x32\xe3\x01\n\x11MessageComparator\x12\x66\n\x17\x63ompareFilterVsMessages\x12$.util.CompareFilterVsMessagesRequest\x1a%.util.CompareFilterVsMessagesResponse\x12\x66\n\x17\x63ompareMessageVsMessage\x12$.util.CompareMessageVsMessageRequest\x1a%.util.CompareMessageVsMessageResponseB\x1e\n\x1a\x63om.exactpro.th2.util.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_util.util_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.exactpro.th2.util.grpcP\001'
  _COMPARISONENTRY_FIELDSENTRY._options = None
  _COMPARISONENTRY_FIELDSENTRY._serialized_options = b'8\001'
  _COMPARISONENTRYTYPE._serialized_start=1254
  _COMPARISONENTRYTYPE._serialized_end=1302
  _COMPARISONENTRYSTATUS._serialized_start=1304
  _COMPARISONENTRYSTATUS._serialized_end=1359
  _COMPARISONSETTINGS._serialized_start=64
  _COMPARISONSETTINGS._serialized_end=107
  _COMPAREFILTERVSMESSAGESREQUEST._serialized_start=110
  _COMPAREFILTERVSMESSAGESREQUEST._serialized_end=246
  _COMPAREFILTERVSMESSAGESRESPONSE._serialized_start=248
  _COMPAREFILTERVSMESSAGESRESPONSE._serialized_end=345
  _COMPAREFILTERVSMESSAGERESULT._serialized_start=347
  _COMPAREFILTERVSMESSAGERESULT._serialized_end=459
  _COMPAREMESSAGEVSMESSAGEREQUEST._serialized_start=461
  _COMPAREMESSAGEVSMESSAGEREQUEST._serialized_end=554
  _COMPAREMESSAGEVSMESSAGERESPONSE._serialized_start=556
  _COMPAREMESSAGEVSMESSAGERESPONSE._serialized_end=654
  _COMPAREMESSAGEVSMESSAGETASK._serialized_start=656
  _COMPAREMESSAGEVSMESSAGETASK._serialized_end=780
  _COMPAREMESSAGEVSMESSAGERESULT._serialized_start=783
  _COMPAREMESSAGEVSMESSAGERESULT._serialized_end=941
  _COMPARISONENTRY._serialized_start=944
  _COMPARISONENTRY._serialized_end=1252
  _COMPARISONENTRY_FIELDSENTRY._serialized_start=1184
  _COMPARISONENTRY_FIELDSENTRY._serialized_end=1252
  _MESSAGECOMPARATOR._serialized_start=1362
  _MESSAGECOMPARATOR._serialized_end=1589
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import th2_grpc_common.common_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ComparisonEntryType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ComparisonEntryTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ComparisonEntryType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FIELD: _ComparisonEntryType.ValueType  # 0
    COLLECTION: _ComparisonEntryType.ValueType  # 1
class ComparisonEntryType(_ComparisonEntryType, metaclass=_ComparisonEntryTypeEnumTypeWrapper):
    pass

FIELD: ComparisonEntryType.ValueType  # 0
COLLECTION: ComparisonEntryType.ValueType  # 1
global___ComparisonEntryType = ComparisonEntryType


class _ComparisonEntryStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ComparisonEntryStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ComparisonEntryStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NA: _ComparisonEntryStatus.ValueType  # 0
    PASSED: _ComparisonEntryStatus.ValueType  # 1
    FAILED: _ComparisonEntryStatus.ValueType  # 2
class ComparisonEntryStatus(_ComparisonEntryStatus, metaclass=_ComparisonEntryStatusEnumTypeWrapper):
    pass

NA: ComparisonEntryStatus.ValueType  # 0
PASSED: ComparisonEntryStatus.ValueType  # 1
FAILED: ComparisonEntryStatus.ValueType  # 2
global___ComparisonEntryStatus = ComparisonEntryStatus


class ComparisonSettings(google.protobuf.message.Message):
    """--// Settings //--//"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IGNORE_FIELDS_FIELD_NUMBER: builtins.int
    @property
    def ignore_fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """
        These fields will not be considered during comparison. It concerns fields with simple or collection types.
        Comparison result will have the NA status for them.
        """
        pass
    def __init__(self,
        *,
        ignore_fields: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_fields",b"ignore_fields"]) -> None: ...
global___ComparisonSettings = ComparisonSettings

class CompareFilterVsMessagesRequest(google.protobuf.message.Message):
    """--// Compare filter versus messages //--//

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILTER_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> th2_grpc_common.common_pb2.MessageFilter: ...
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.Message]: ...
    @property
    def settings(self) -> global___ComparisonSettings: ...
    def __init__(self,
        *,
        filter: typing.Optional[th2_grpc_common.common_pb2.MessageFilter] = ...,
        messages: typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.Message]] = ...,
        settings: typing.Optional[global___ComparisonSettings] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter",b"filter","settings",b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter",b"filter","messages",b"messages","settings",b"settings"]) -> None: ...
global___CompareFilterVsMessagesRequest = CompareFilterVsMessagesRequest

class CompareFilterVsMessagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMPARISON_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def comparison_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompareFilterVsMessageResult]: ...
    def __init__(self,
        *,
        comparison_results: typing.Optional[typing.Iterable[global___CompareFilterVsMessageResult]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_results",b"comparison_results"]) -> None: ...
global___CompareFilterVsMessagesResponse = CompareFilterVsMessagesResponse

class CompareFilterVsMessageResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    COMPARISON_RESULT_FIELD_NUMBER: builtins.int
    @property
    def message_id(self) -> th2_grpc_common.common_pb2.MessageID: ...
    @property
    def comparison_result(self) -> global___ComparisonEntry: ...
    def __init__(self,
        *,
        message_id: typing.Optional[th2_grpc_common.common_pb2.MessageID] = ...,
        comparison_result: typing.Optional[global___ComparisonEntry] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comparison_result",b"comparison_result","message_id",b"message_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_result",b"comparison_result","message_id",b"message_id"]) -> None: ...
global___CompareFilterVsMessageResult = CompareFilterVsMessageResult

class CompareMessageVsMessageRequest(google.protobuf.message.Message):
    """--// Compare message versus message //--//

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMPARISON_TASKS_FIELD_NUMBER: builtins.int
    @property
    def comparison_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompareMessageVsMessageTask]: ...
    def __init__(self,
        *,
        comparison_tasks: typing.Optional[typing.Iterable[global___CompareMessageVsMessageTask]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_tasks",b"comparison_tasks"]) -> None: ...
global___CompareMessageVsMessageRequest = CompareMessageVsMessageRequest

class CompareMessageVsMessageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMPARISON_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def comparison_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompareMessageVsMessageResult]: ...
    def __init__(self,
        *,
        comparison_results: typing.Optional[typing.Iterable[global___CompareMessageVsMessageResult]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_results",b"comparison_results"]) -> None: ...
global___CompareMessageVsMessageResponse = CompareMessageVsMessageResponse

class CompareMessageVsMessageTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FIRST_FIELD_NUMBER: builtins.int
    SECOND_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def first(self) -> th2_grpc_common.common_pb2.Message: ...
    @property
    def second(self) -> th2_grpc_common.common_pb2.Message: ...
    @property
    def settings(self) -> global___ComparisonSettings: ...
    def __init__(self,
        *,
        first: typing.Optional[th2_grpc_common.common_pb2.Message] = ...,
        second: typing.Optional[th2_grpc_common.common_pb2.Message] = ...,
        settings: typing.Optional[global___ComparisonSettings] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["first",b"first","second",b"second","settings",b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["first",b"first","second",b"second","settings",b"settings"]) -> None: ...
global___CompareMessageVsMessageTask = CompareMessageVsMessageTask

class CompareMessageVsMessageResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FIRST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    SECOND_MESSAGE_ID_FIELD_NUMBER: builtins.int
    COMPARISON_RESULT_FIELD_NUMBER: builtins.int
    @property
    def first_message_id(self) -> th2_grpc_common.common_pb2.MessageID: ...
    @property
    def second_message_id(self) -> th2_grpc_common.common_pb2.MessageID: ...
    @property
    def comparison_result(self) -> global___ComparisonEntry: ...
    def __init__(self,
        *,
        first_message_id: typing.Optional[th2_grpc_common.common_pb2.MessageID] = ...,
        second_message_id: typing.Optional[th2_grpc_common.common_pb2.MessageID] = ...,
        comparison_result: typing.Optional[global___ComparisonEntry] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comparison_result",b"comparison_result","first_message_id",b"first_message_id","second_message_id",b"second_message_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_result",b"comparison_result","first_message_id",b"first_message_id","second_message_id",b"second_message_id"]) -> None: ...
global___CompareMessageVsMessageResult = CompareMessageVsMessageResult

class ComparisonEntry(google.protobuf.message.Message):
    """--// Common entry //--//

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class FieldsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___ComparisonEntry: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___ComparisonEntry] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FIRST_FIELD_NUMBER: builtins.int
    SECOND_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    IS_KEY_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    type: global___ComparisonEntryType.ValueType
    """The type field has default value for a root element and it should be skipped during analyse. It has real value for other fields."""

    status: global___ComparisonEntryStatus.ValueType
    """
    The status field has default value for a element with collection type and it should be skipped during analyse.
    It has real value for other fields. Fields with nested elements have aggregated value.
    """

    first: typing.Text
    """The first field has default value for a root element and it should be skipped during analyse. It has value of the first message of filter in other cases."""

    second: typing.Text
    """The second field has default value for a root element and it should be skipped during analyse. It has value of the second message in other cases."""

    operation: th2_grpc_common.common_pb2.FilterOperation.ValueType
    """
    The operation field has default value for a root element and it should be skipped during analyse.
    This value is taken from filter in case filter vs message comparison or it is EQUAL in case message vs message comparison.
    """

    is_key: builtins.bool
    """
    The is_key field has default value for a root element and it should be skipped during analyse.
    It is taken from filter in case filter versus message comparison otherwise it is false.
    """

    @property
    def fields(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___ComparisonEntry]:
        """The fields contains mapping name to ComparisonEntry for nested fields."""
        pass
    def __init__(self,
        *,
        type: global___ComparisonEntryType.ValueType = ...,
        status: global___ComparisonEntryStatus.ValueType = ...,
        first: typing.Text = ...,
        second: typing.Text = ...,
        operation: th2_grpc_common.common_pb2.FilterOperation.ValueType = ...,
        is_key: builtins.bool = ...,
        fields: typing.Optional[typing.Mapping[typing.Text, global___ComparisonEntry]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fields",b"fields","first",b"first","is_key",b"is_key","operation",b"operation","second",b"second","status",b"status","type",b"type"]) -> None: ...
global___ComparisonEntry = ComparisonEntry



from . import util_pb2_grpc as importStub

class MessageComparatorService(object):

    def __init__(self, router):
        self.connector = router.get_connection(MessageComparatorService, importStub.MessageComparatorStub)

    def compareFilterVsMessages(self, request, timeout=None):
        return self.connector.create_request('compareFilterVsMessages', request, timeout)

    def compareMessageVsMessage(self, request, timeout=None):
        return self.connector.create_request('compareMessageVsMessage', request, timeout)